==> adapter-vue-4.2.2.tgz: package/bundles/index.js <==
'use strict';

var core = require('@textbus/core');
var vue = require('vue');
var platformBrowser = require('@textbus/platform-browser');
var core$1 = require('@viewfly/core');

const adapterError = core.makeError('VueAdapter');
class VueAdapter extends platformBrowser.DomAdapter {
    constructor(components, mount) {
        super({
            createCompositionNode: (compositionState, updateNativeCompositionNode) => {
                return new core.VElement('span', {
                    style: {
                        textDecoration: 'underline'
                    },
                    ref: updateNativeCompositionNode
                }, [
                    new core.VTextNode(compositionState.text)
                ]);
            },
            getParentNode(node) {
                return node.parentNode;
            },
            getChildNodes(parentElement) {
                return Array.from(parentElement.childNodes);
            },
            isNativeElementNode(node) {
                return node instanceof Element;
            },
            getChildByIndex(parentElement, index) {
                return parentElement.childNodes[index];
            },
            getAndUpdateSlotRootNativeElement(vElement, update) {
                const currentRef = vElement.attrs.get('ref');
                if (currentRef) {
                    vElement.attrs.set('ref', (v) => {
                        update(v);
                        if (typeof currentRef === 'function') {
                            currentRef(v);
                        }
                        else if (!currentRef.value) {
                            currentRef.value = v;
                        }
                    });
                }
                else {
                    vElement.attrs.set('ref', update);
                }
            },
            componentRender: (component) => {
                const comp = this.components[component.name] || this.components['*'];
                if (comp) {
                    let rootRef = this.componentRefs.get(component);
                    if (!rootRef) {
                        rootRef = vue.ref();
                        this.componentRefs.set(component, rootRef);
                    }
                    return vue.h(comp, {
                        component,
                        rootRef,
                        key: component.id
                    });
                }
                throw adapterError(`cannot found view component \`${component.name}\`!`);
            },
            vElementToViewElement(vNode, children) {
                const props = Object.assign({}, (Array.from(vNode.attrs).reduce((a, b) => {
                    a[b[0]] = b[1];
                    return a;
                }, {})));
                if (vNode.classes.size) {
                    props.class = Array.from(vNode.classes).join(' ');
                }
                if (vNode.styles) {
                    props.style = Array.from(vNode.styles).reduce((a, b) => {
                        a[b[0]] = b[1];
                        return a;
                    }, {});
                }
                return vue.h(vNode.tagName, props, ...children);
            }
        }, mount);
        // private compositionRef = ref<Element>()
        this.componentRefs = new WeakMap();
        this.components = {};
        // watchEffect(() => {
        //   this.compositionNode = this.compositionRef.value || null
        // })
        Object.keys(components).forEach(key => {
            const vueComponent = components[key];
            const setup = vueComponent.setup;
            const self = this;
            vueComponent.setup = function (props, context, ...args) {
                const component = props.component;
                const vueInstance = vue.getCurrentInstance();
                const sub = component.changeMarker.onChange.subscribe(() => {
                    if (component.changeMarker.dirty) {
                        vueInstance.proxy.$forceUpdate();
                    }
                });
                vue.onMounted(() => {
                    if (props.rootRef.value) {
                        self.componentRootElementCaches.set(component, props.rootRef.value);
                    }
                    else {
                        self.componentRootElementCaches.remove(component);
                    }
                });
                vue.onUpdated(() => {
                    var _a;
                    component.changeMarker.rendered();
                    self.onViewUpdated.next();
                    if (!(((_a = self.componentRefs.get(component)) === null || _a === void 0 ? void 0 : _a.value) instanceof Element)) {
                        // eslint-disable-next-line max-len
                        throw adapterError(`Component \`${component.name}\` is not bound to rootRef, you must bind rootRef to the root element node of the component view.`);
                    }
                });
                vue.onUnmounted(() => {
                    sub.unsubscribe();
                });
                return setup(props, context, ...args);
            };
            this.components[key] = vueComponent;
        });
    }
    render(rootComponent, injector) {
        const childrenInjector = new core$1.ReflectiveInjector(injector, [{
                provide: core.Adapter,
                useValue: this
            }, {
                provide: platformBrowser.DomAdapter,
                useValue: this,
            }, {
                provide: VueAdapter,
                useValue: this
            }]);
        return super.render(rootComponent, childrenInjector);
    }
    copy() {
        document.execCommand('copy');
    }
}

exports.VueAdapter = VueAdapter;

==> adapter-vue-4.3.4.tgz: package/bundles/index.js <==
'use strict';

var core = require('@textbus/core');
var vue = require('vue');
var platformBrowser = require('@textbus/platform-browser');
var core$1 = require('@viewfly/core');
var stream = require('@tanbo/stream');

const adapterError = core.makeError('VueAdapter');
class VueAdapter extends platformBrowser.DomAdapter {
    constructor(components, mount) {
        super({
            createCompositionNode: (compositionState, updateNativeCompositionNode) => {
                return new core.VElement('span', {
                    style: {
                        textDecoration: 'underline'
                    },
                    ref: updateNativeCompositionNode
                }, [
                    new core.VTextNode(compositionState.text)
                ]);
            },
            getParentNode(node) {
                return node.parentNode;
            },
            getChildNodes(parentElement) {
                return Array.from(parentElement.childNodes);
            },
            isNativeElementNode(node) {
                return node instanceof Element;
            },
            getChildByIndex(parentElement, index) {
                return parentElement.childNodes[index];
            },
            getAndUpdateSlotRootNativeElement(vElement, update) {
                const currentRef = vElement.attrs.get('ref');
                if (currentRef) {
                    vElement.attrs.set('ref', (v) => {
                        update(v);
                        if (typeof currentRef === 'function') {
                            currentRef(v);
                        }
                        else if (!currentRef.value) {
                            currentRef.value = v;
                        }
                    });
                }
                else {
                    vElement.attrs.set('ref', update);
                }
            },
            componentRender: (component) => {
                const comp = this.components[component.name] || this.components['*'];
                if (comp) {
                    let rootRef = this.componentRefs.get(component);
                    if (!rootRef) {
                        rootRef = vue.ref();
                        this.componentRefs.set(component, rootRef);
                    }
                    return vue.h(comp, {
                        component,
                        rootRef,
                        key: component.id
                    });
                }
                throw adapterError(`cannot found view component \`${component.name}\`!`);
            },
            vElementToViewElement(vNode, children) {
                const props = Object.assign({}, (Array.from(vNode.attrs).reduce((a, b) => {
                    a[b[0]] = b[1];
                    return a;
                }, {})));
                if (vNode.classes.size) {
                    props.class = Array.from(vNode.classes).join(' ');
                }
                if (vNode.styles) {
                    props.style = Array.from(vNode.styles).reduce((a, b) => {
                        a[b[0]] = b[1];
                        return a;
                    }, {});
                }
                return vue.h(vNode.tagName, props, ...children);
            }
        }, mount);
        // private compositionRef = ref<Element>()
        this.componentRefs = new WeakMap();
        this.components = {};
        // watchEffect(() => {
        //   this.compositionNode = this.compositionRef.value || null
        // })
        Object.keys(components).forEach(key => {
            const vueComponent = components[key];
            const setup = vueComponent.setup;
            const self = this;
            vueComponent.setup = function (props, context, ...args) {
                const component = props.component;
                const vueInstance = vue.getCurrentInstance();
                const sub = stream.merge(component.changeMarker.onChange, component.changeMarker.onForceChange).subscribe(() => {
                    if (component.changeMarker.dirty) {
                        vueInstance.proxy.$forceUpdate();
                    }
                });
                vue.onMounted(() => {
                    if (props.rootRef.value) {
                        self.componentRootElementCaches.set(component, props.rootRef.value);
                    }
                    else {
                        self.componentRootElementCaches.remove(component);
                    }
                });
                vue.onUpdated(() => {
                    var _a;
                    component.changeMarker.rendered();
                    self.onViewUpdated.next();
                    if (!(((_a = self.componentRefs.get(component)) === null || _a === void 0 ? void 0 : _a.value) instanceof Element)) {
                        // eslint-disable-next-line max-len
                        throw adapterError(`Component \`${component.name}\` is not bound to rootRef, you must bind rootRef to the root element node of the component view.`);
                    }
                });
                vue.onUnmounted(() => {
                    sub.unsubscribe();
                });
                return setup(props, context, ...args);
            };
            this.components[key] = vueComponent;
        });
    }
    render(rootComponent, injector) {
        const childrenInjector = new core$1.ReflectiveInjector(injector, [{
                provide: core.Adapter,
                useValue: this
            }, {
                provide: platformBrowser.DomAdapter,
                useValue: this,
            }, {
                provide: VueAdapter,
                useValue: this
            }]);
        return super.render(rootComponent, childrenInjector);
    }
    copy() {
        document.execCommand('copy');
    }
}

exports.VueAdapter = VueAdapter;
